@@ -13,6 +13,5 @@
 #' @useDynLib naryn emr_dbinit emr_dbreload emr_dbunload emr_db_subset emr_db_subset_ids emr_db_subset_info emr_covariance emr_ids_dist emr_ids_dist_with_iterator emr_ids_vals_dist emr_check_named_filter emr_check_filter_attr_src emr_check_filter_attr_time_shift emr_check_filter_attr_expiration update_logical_tracks_file emr_create_logical emr_remove_logical emr_is_logical emr_logical_track_info emr_ltrack_dependencies emr_get_tracks_attrs update_tracks_attrs_file emr_set_track_attr emr_track_create emr_track_exists emr_logical_track_exists emr_logical_track_names emr_track_db_names emr_track_ids emr_import emr_logical_track_user_info emr_track_info emr_track_names emr_track_mv emr_track_percentile emr_track_rm emr_track_unique emr_check_vtrack emr_check_vtrack_attr_src emr_check_vtrack_attr_func emr_check_vtrack_attr_time_shift emr_check_vtrack_attr_id_map emr_check_vtrack_attr_filter
 #' @useDynLib naryn C_emr_dist C_emr_extract C_emr_quantiles C_emr_screen C_emr_summary C_emr_time2hour C_emr_time2dayofmonth C_emr_time2month C_emr_time2year C_emr_date2time C_emr_annotate
 #' @aliases naryn-package naryn
-#' @docType package
 #' @keywords package
-NULL
+"_PACKAGE"
