@@ -4,22 +4,22 @@
 
 BinsManager::BinsManager(SEXP _breaks, SEXP _include_lowest, SEXP _right, const vector<string> *exprs, const NRTrackExpressionVars *expr_vars)
 {
-	if (!isVector(_breaks)){
+	if (!Rf_isVector(_breaks)){
 		TGLError<BinsManager>("'breaks' argument must be a vector");
     }
 
-	if (!isLogical(_include_lowest) || Rf_length(_include_lowest) != 1){
+	if (!Rf_isLogical(_include_lowest) || Rf_length(_include_lowest) != 1){
 		TGLError<BinsManager>("'include.lowest' argument is not logical");
     }
 
-    if (!isLogical(_right) || Rf_length(_right) != 1){
+    if (!Rf_isLogical(_right) || Rf_length(_right) != 1){
         TGLError<BinsManager>("'right' argument is not logical");
     }
 
 	unsigned num_breaks_sets = Rf_length(_breaks);
 
-	m_include_lowest = asLogical(_include_lowest);
-    m_right = asLogical(_right);
+	m_include_lowest = Rf_asLogical(_include_lowest);
+    m_right = Rf_asLogical(_right);
 	m_bin_finders.reserve(num_breaks_sets);
 	m_track_mult.resize(num_breaks_sets);
     m_tracks.resize(num_breaks_sets, NULL);
@@ -28,19 +28,19 @@ BinsManager::BinsManager(SEXP _breaks, SEXP _include_lowest, SEXP _right, const
 	for (unsigned i = 0; i < num_breaks_sets; ++i) {
 		SEXP breaks = VECTOR_ELT(_breaks, i);
 
-		if ((expr_vars && !isNull(breaks) && !isReal(breaks) && !isInteger(breaks)) || (!expr_vars && !isReal(breaks) && !isInteger(breaks))){
+		if ((expr_vars && !Rf_isNull(breaks) && !Rf_isReal(breaks) && !Rf_isInteger(breaks)) || (!expr_vars && !Rf_isReal(breaks) && !Rf_isInteger(breaks))){
 			TGLError<BinsManager>("breaks[%d] is not numeric", i + 1);
         }
 
 		m_bin_finders.push_back(BinFinder());
 
-		if (isInteger(breaks)) {
+		if (Rf_isInteger(breaks)) {
 			vector<double> double_breaks(Rf_length(breaks));
 
 			for (int i = 0; i < Rf_length(breaks); i++)
 				double_breaks[i] = INTEGER(breaks)[i];
 			m_bin_finders.back().init(double_breaks, m_include_lowest, m_right);
-		} else if (isReal(breaks))
+		} else if (Rf_isReal(breaks))
 			m_bin_finders.back().init(REAL(breaks), Rf_length(breaks), m_include_lowest, m_right);
         else {  // breaks is NULL
             const NRTrackExpressionVars::TrackVar *var = expr_vars->var((*exprs)[i].c_str());
@@ -94,7 +94,7 @@ void BinsManager::set_dims(SEXP dim, SEXP dimnames, SEXP breaks_set) const
             for (vector<double>::const_iterator ival = vals.begin(); ival < vals.end(); ++ival) {
                 char buf[100];
                 snprintf(buf, sizeof(buf), "%d", (int)*ival);
-                SET_STRING_ELT(dimname, ival - vals.begin(), mkChar(buf));
+                SET_STRING_ELT(dimname, ival - vals.begin(), Rf_mkChar(buf));
                 INTEGER(breaks)[ival - vals.begin()] = (int)*ival;
             }
         } else {
@@ -111,7 +111,7 @@ void BinsManager::set_dims(SEXP dim, SEXP dimnames, SEXP breaks_set) const
                 } else {
                     snprintf(buf, sizeof(buf), "[%g,%g%c", bin_finder.get_breaks()[j], bin_finder.get_breaks()[j + 1], j != numbins - 1 || !m_include_lowest ? ')' : ']');
                 }
-    			SET_STRING_ELT(dimname, j, mkChar(buf));
+    			SET_STRING_ELT(dimname, j, Rf_mkChar(buf));
                 REAL(breaks)[j] = bin_finder.get_breaks()[j];
     		}
             REAL(breaks)[numbins] = bin_finder.get_breaks()[numbins];
