@@ -8,6 +8,9 @@
 #include <string.h>
 #include <cstdint>
 
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
 #include <R.h>
 #include <Rinternals.h>
 
