@@ -1,3 +1,6 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
 #include <R.h>
 #include <R_ext/Rdynload.h>
 #include <Rinternals.h>
